aboutsummaryrefslogtreecommitdiff
path: root/engines/sci/engine/script.h
diff options
context:
space:
mode:
authorFilippos Karapetis2010-11-04 23:19:23 +0000
committerFilippos Karapetis2010-11-04 23:19:23 +0000
commit7d71d07075e1331816688f11be11318ccbd32cd0 (patch)
tree9b2614e4630277f0ffca5b2f079adf1dffc93371 /engines/sci/engine/script.h
parent1e59b9dd2ca15f36543ee2a16a01b57d792689c3 (diff)
downloadscummvm-rg350-7d71d07075e1331816688f11be11318ccbd32cd0.tar.gz
scummvm-rg350-7d71d07075e1331816688f11be11318ccbd32cd0.tar.bz2
scummvm-rg350-7d71d07075e1331816688f11be11318ccbd32cd0.zip
SCI: Renamed findBlock() to findBlockSCI0()
svn-id: r54077
Diffstat (limited to 'engines/sci/engine/script.h')
-rw-r--r--engines/sci/engine/script.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/engines/sci/engine/script.h b/engines/sci/engine/script.h
index e316fc0c8d..04603ad829 100644
--- a/engines/sci/engine/script.h
+++ b/engines/sci/engine/script.h
@@ -238,9 +238,10 @@ public:
void mcpyInOut(int dst, const void *src, size_t n);
/**
* Finds the pointer where a block of a specific type starts from
*/
- byte *findBlock(int type, int skipBlockIndex = -1);
+ byte *findBlockSCI0(int type, int startBlockIndex = -1);
private:
/**
@@ -267,6 +268,8 @@ private:
* @param segmentId The script's segment id
*/
void initialiseObjectsSci11(SegManager *segMan, SegmentId segmentId);
+
+ void syncHeap(Common::Serializer &ser);
};
} // End of namespace Sci
@@ -238,9 +238,10 @@ public:
void mcpyInOut(int dst, const void *src, size_t n);
/**
- * Finds the pointer where a block of a specific type starts from
+ * Finds the pointer where a block of a specific type starts from,
+ * in SCI0 - SCI1 games
*/